import { QuizQuestionDate } from './date';
import { QuizQuestionEmoji } from './emoji';
import { QuizQuestionFile } from './file';
import { QuizQuestionImages } from './images';
import { QuizQuestionNumber } from './number';
import { QuizQuestionPage } from './page';
import { QuizQuestionRating } from './rating';
import { QuizQuestionResult } from './result';
import { QuizQuestionSelect } from './select';
import { QuizQuestionText } from './text';
import { QuizQuestionVariant } from './variant';
import { QuizQuestionVarImg } from './varimg';

export interface QuestionBranchingRuleMain {
    next: string;
    or: boolean;
    rules: {
        question: string;
        answers: string[];
    }[];
}
export type EditedImagesScreens = "desktop" | "tablet" | "mobile" | "small";
export type EditedUrlImagesList = Record<EditedImagesScreens, string>;
export interface QuestionBranchingRule {
    children: string[];
    main: QuestionBranchingRuleMain[];
    parentId: string | null | "root";
    default: string;
}
export interface QuestionHint {
    /** Текст подсказки */
    text: string;
    /** URL видео подсказки */
    video: string;
}
export type QuestionVariant = {
    id: string;
    /** Текст */
    answer: string;
    /** Текст подсказки */
    hints: string;
    /** Дополнительное поле для текста, emoji, ссылки на картинку */
    extendedText: string;
    isOwn?: boolean;
    isMulti?: boolean;
    /** Оригинал изображения (до кропа) */
    originalImageUrl: string;
    points?: number;
};
export interface QuestionVariantWithEditedImages extends QuestionVariant {
    editedUrlImagesList?: EditedUrlImagesList | null;
}
export type QuestionType = "variant" | "images" | "varimg" | "emoji" | "text" | "select" | "date" | "number" | "file" | "page" | "rating" | "result";
export interface QuizQuestionBase {
    backendId: number;
    /** Stable id, generated on client */
    id: string;
    quizId: number;
    title: string;
    description: string;
    page: number;
    type?: QuestionType | null;
    expanded: boolean;
    openedModalSettings: boolean;
    deleted: boolean;
    required: boolean;
    deleteTimeoutId: number;
    content: {
        id: string;
        hint: QuestionHint;
        rule: QuestionBranchingRule;
        back: string | null;
        originalBack: string | null;
        autofill: boolean;
    };
}
export type AnyTypedQuizQuestion = QuizQuestionVariant | QuizQuestionImages | QuizQuestionVarImg | QuizQuestionEmoji | QuizQuestionText | QuizQuestionSelect | QuizQuestionDate | QuizQuestionNumber | QuizQuestionFile | QuizQuestionPage | QuizQuestionRating | QuizQuestionResult;
export type RealTypedQuizQuestion = Exclude<AnyTypedQuizQuestion, QuizQuestionResult>;
type FilterQuestionsWithVariants<T> = T extends {
    content: {
        variants: QuestionVariant[];
    };
} ? T : never;
export type QuizQuestionsWithVariants = FilterQuestionsWithVariants<AnyTypedQuizQuestion>;
export {};
